Recently Written · git

cl-yag

Mirror and rewrite of Solène Rapenne's cl-yag SSG of renown

git clone https://github.com/equwal/cl-yag

Log | Files | Refs


commit 5c6b061bb6f819e9e5a3bd028c5683e3b6227815
Solene Rapenne <solene@perso.pw>
2017-12-31 16:54:23 +0100

More verbose configuration

 data/articles.lisp | 8 ++++----
 1 file changed, 4 insertions(+), 4 deletions(-)
diff --git a/data/articles.lisp b/data/articles.lisp
index 6d32a55..d64bff6 100644
--- a/data/articles.lisp
+++ b/data/articles.lisp
@@ -17,10 +17,10 @@
    :gopher-path      "/user"                            ;; absolute path of your gopher directory
    :gopher-server    "my.website"                       ;; hostname of the gopher server
    :gopher-port      "70"                               ;; tcp port of the gopher server, 70 usually
-   :gopher-format "[0|~a|~a/article-~d.txt|~a|~a]~%~%"  ;; geomyidae
-   :gopher-index "index.gph"                            ;; geomyidae
-   ;; :gopher-format "0~a	~a/article-~d.txt	~a	~a~%~%" ;; gophernicus and others
-   ;; :gopher-index "gophermap"                         ;; gophernicus and others
+   :gopher-format "[0|~a|~a/article-~d.txt|~a|~a]~%~%"  ;; menu format (geomyidae)
+   :gopher-index "index.gph"                            ;; menu file   (geomyidae)
+   ;; :gopher-format "0~a	~a/article-~d.txt	~a	~a~%~%" ;; menu format (gophernicus and others)
+   ;; :gopher-index "gophermap"                         ;; menu file (gophernicus and others)
    ))